Module ipc

Module ipc 

IPC transport via Unix domain sockets.

Provides Unix domain socket support for inter-process communication with zero-copy and low-latency characteristics.

Structs

IpcListener
A bound Unix domain socket listener that unlinks its socket file on drop.

Functions

accept
Accept a connection on a Unix domain socket listener.
bind
Bind a Unix domain socket listener.
connect
Connect to a Unix domain socket.