create_monitor

Function create_monitor 

pub fn create_monitor() -> (SocketEventSender, SocketMonitor)
Creates a new monitoring channel pair.

The channel is bounded by MONITOR_CHANNEL_CAP. Emit events with emit, which never blocks the caller.

This is exposed publicly to allow socket implementations to create monitors.