pub async fn join<T>(handle: JoinHandle<T>) -> TExpand description
Await a spawned task and return its output.
Normalizes the difference between backends: compio’s task awaits directly to the output, so this is just the await.
pub async fn join<T>(handle: JoinHandle<T>) -> TAwait a spawned task and return its output.
Normalizes the difference between backends: compio’s task awaits directly to the output, so this is just the await.