pub fn spawn<F>(fut: F) -> JoinHandle<F::Output>where
F: Future + 'static,Expand description
Spawn a task on the current runtime and return its handle.
pub fn spawn<F>(fut: F) -> JoinHandle<F::Output>where
F: Future + 'static,Spawn a task on the current runtime and return its handle.