pub fn create_monitor() -> (SocketEventSender, SocketMonitor)Expand description
Creates a new monitoring channel pair.
This is exposed publicly to allow socket implementations to create monitors.
pub fn create_monitor() -> (SocketEventSender, SocketMonitor)Creates a new monitoring channel pair.
This is exposed publicly to allow socket implementations to create monitors.